Flask-Magql
===========

[Magql][] is a [GraphQL][] framework for Python. It's pronounced "magical", and
it is! This extension allows serving a Magql GraphQL API with [Flask][].

-   Implements the [GraphQL multipart request specification][multipart] to allow
    uploading files with a GraphQL operation.
-   Implements batched operations.
-   Provides the [GraphiQL][] UI for exploring the schema and building queries.

[Magql]: https://magql.autoinvent.dev
[GraphQL]: https://graphql.org
[Flask]: https://flask.palletsprojects.com
[multipart]: https://github.com/jaydenseric/graphql-multipart-request-spec
[GraphiQL]: https://github.com/graphql/graphiql/tree/main/packages/graphiql#readme

```{toctree}
:hidden:

start
multipart
api
changes
license
```
